@@ -1,7 +1,6 @@
-<?php
+<?php declare(strict_types = 1);
 namespace TheSeer\phpDox\Collector;
 
 class TraitUseException extends \Exception {
-
-    const NotAliased = 1;
+    public const NotAliased = 1;
 }
